@@ -1,9 +1,8 @@
-from .base_command import BaseCommand
-from bond.cli.table import Table
-import time
 import bond.proto
 from bond.database import BondDatabase
 
+from .base_command import BaseCommand
+
 
 class VersionCommand(BaseCommand):
     subcmd = "version"
